==> aptechka-0.41.6.tgz: package/lib/layout-box/index.js <==
var Q = (i) => {
  throw TypeError(i);
};
var K = (i, e, s) => e.has(i) || Q("Cannot " + s);
var t = (i, e, s) => (K(i, e, "read from private field"), s ? s.call(i) : e.get(i)), h = (i, e, s) => e.has(i) ? Q("Cannot add the same private member more than once") : e instanceof WeakSet ? e.add(i) : e.set(i, s), r = (i, e, s, l) => (K(i, e, "write to private field"), l ? l.call(i, s) : e.set(i, s), s), L = (i, e, s) => (K(i, e, "access private method"), s);
import { cssUnitParser as ut } from "../css-unit-parser/index.js";
import { Ladder as N } from "../ladder/index.js";
import { RESIZE_ORDER as St, TICK_ORDER as dt } from "../order/index.js";
import { scrollEntries as $ } from "../scroll-entries/index.js";
import { ticker as j } from "../ticker/vanilla/index.js";
import { i as tt } from "../browser-0zX67oeU.js";
import { g as et } from "../dom-0S_WDL4g.js";
import { g as F, a as G } from "../layout-HoBT_Da2.js";
import { elementResizer as st } from "../element-resizer/vanilla/index.js";
import { windowResizer as it } from "../window-resizer/vanilla/index.js";
import { Notifier as ft } from "../notifier/index.js";
function pt(i) {
  const e = Math.sqrt(
    i.m11 * i.m11 + i.m12 * i.m12 + i.m13 * i.m13
  ), s = Math.sqrt(
    i.m21 * i.m21 + i.m22 * i.m22 + i.m23 * i.m23
  ), l = Math.sqrt(
    i.m31 * i.m31 + i.m32 * i.m32 + i.m33 * i.m33
  ), y = Math.atan2(i.m32, i.m33), A = Math.atan2(
    -i.m31,
    Math.sqrt(i.m32 * i.m32 + i.m33 * i.m33)
  ), k = Math.atan2(i.m21, i.m11), u = i.m41, V = i.m42 * -1, O = i.m43;
  return {
    scaleX: e,
    scaleY: s,
    scaleZ: l,
    rotationX: y,
    rotationY: A,
    rotationZ: k,
    translationX: u,
    translationY: V,
    translationZ: O
  };
}
var a, z, b, _, W, X, v, w, q, B, x, M, Y, S, d, C, H, I, D, p, g, m, c, n, o, E, R, T, f, J, ht, rt, nt, P, U, Z;
class Ct {
  constructor(e, s) {
    h(this, f);
    h(this, a, null);
    h(this, z, null);
    h(this, b, []);
    h(this, _, "auto");
    h(this, W, "top");
    h(this, X, !1);
    h(this, v, !0);
    h(this, w, !0);
    h(this, q, !0);
    h(this, B, !0);
    h(this, x, 0);
    h(this, M, 0);
    h(this, Y, 0);
    h(this, S, 0);
    h(this, d, 0);
    h(this, C, 0);
    h(this, H, 0);
    h(this, I, 0);
    h(this, D, 0);
    h(this, p, { x: 0, y: 0, z: 0 });
    h(this, g, { x: 0, y: 0, z: 0 });
    h(this, m, { x: 1, y: 1, z: 1 });
    h(this, c, new N({ x: 0, y: 0, z: 0 }));
    h(this, n, new N({ x: 0, y: 0, z: 0 }));
    h(this, o, new N({ x: 0, y: 0, z: 0 }));
    h(this, E, { x: 0, y: 0, z: 0 });
    h(this, R, /* @__PURE__ */ new Map());
    h(this, T, new ft());
    h(this, P, () => {
      tt && L(this, f, rt).call(this);
    });
    h(this, U, () => {
      L(this, f, nt).call(this), L(this, f, J).call(this);
    });
    h(this, Z, () => {
      const e = $.getAll(this.element);
      t(this, R).forEach((s, l) => {
        e.includes(l) || (this.deleteScrollStep(s), t(this, R).delete(l));
      }), e.forEach((s) => {
        if (!t(this, R).has(s)) {
          const l = () => s;
          t(this, R).set(s, l), this.setScrollStep(l);
        }
      });
    });
    tt && (r(this, a, et(e) || document.body), r(this, z, et(s == null ? void 0 : s.containerElement) || document.body), r(this, _, (s == null ? void 0 : s.scrollAxis) || "auto"), r(this, W, (s == null ? void 0 : s.frontSide) || "top"), r(this, X, (s == null ? void 0 : s.cartesian) || !1), r(this, v, (s == null ? void 0 : s.sizeStep) !== void 0 ? s.sizeStep : !0), r(this, w, (s == null ? void 0 : s.positionStep) !== void 0 ? s.positionStep : !0), r(this, q, (s == null ? void 0 : s.transformStep) !== void 0 ? s.transformStep : !0), r(this, B, (s == null ? void 0 : s.scrollStep) !== void 0 ? s.scrollStep : !0), t(this, o).setStep("_size", "+", {
      x: 1,
      y: 1,
      z: 1
    }), t(this, n).setStep("_position", "+", {
      x: 0,
      y: 0,
      z: 0
    }), t(this, o).setStep("_scale", "*", {
      x: 1,
      y: 1,
      z: 1
    }), t(this, n).setStep("_translation", "+", {
      x: 0,
      y: 0,
      z: 0
    }), t(this, c).setStep("_rotation", "+", {
      x: 0,
      y: 0,
      z: 0
    }), t(this, B) && ($.notifier.subscribe(t(this, Z)), t(this, Z).call(this)), st.subscribe(this.element, t(this, P)), it.subscribe(t(this, P), St.LAYOUT_BOX), j.subscribe(t(this, U), {
      order: dt.LAYOUT_BOX,
      culling: s != null && s.culling ? this.element : void 0
    }));
  }
  get element() {
    return t(this, a);
  }
  get containerElement() {
    return t(this, z);
  }
  get position() {
    return t(this, n).current;
  }
  get rotation() {
    return t(this, c).current;
  }
  get scale() {
    return t(this, o).current;
  }
  get scrollValue() {
    return t(this, E);
  }
  get left() {
    return t(this, d);
  }
  get top() {
    return t(this, S);
  }
  get CSSTranslation() {
    return t(this, p);
  }
  get CSSRotation() {
    return t(this, g);
  }
  get CSSScale() {
    return t(this, m);
  }
  get front() {
    return t(this, C);
  }
  get width() {
    return t(this, x);
  }
  get height() {
    return t(this, M);
  }
  get depth() {
    return t(this, Y);
  }
  destroy() {
    j.unsubscribe(t(this, U)), st.unsubscribe(t(this, P)), it.unsubscribe(t(this, P)), $.notifier.unsubscribe(t(this, Z)), t(this, R).clear(), t(this, n).close(), t(this, c).close(), t(this, o).close();
  }
  bindObject(e) {
    e.position && t(this, n).bind(e.position), e.rotation && t(this, c).bind(e.rotation), e.scale && t(this, o).bind(e.scale);
  }
  unbindObject(e) {
    e.position && t(this, n).unbind(e.position), e.rotation && t(this, c).unbind(e.rotation), e.scale && t(this, o).unbind(e.scale);
  }
  setScrollStep(e) {
    return t(this, b).includes(e) || t(this, b).push(e), () => this.deleteScrollStep(e);
  }
  deleteScrollStep(e) {
    r(this, b, t(this, b).filter(
      (s) => s !== e
    ));
  }
  setPositionStep(...e) {
    t(this, n).setStep(...e);
  }
  getPositionStep(...e) {
    return t(this, n).getStepValue(...e);
  }
  setRotationStep(...e) {
    t(this, c).setStep(...e);
  }
  getRotationStep(...e) {
    return t(this, c).getStepValue(...e);
  }
  getExcludedRotationSteps(...e) {
    return t(this, c).getExcludedStepsValue(...e);
  }
  getIncludedRotationSteps(...e) {
    return t(this, c).getIncludedStepsValue(...e);
  }
  setScaleStep(...e) {
    t(this, o).setStep(...e);
  }
  getScaleStep(...e) {
    return t(this, o).getStepValue(...e);
  }
  getExcludedScaleSteps(...e) {
    return t(this, o).getExcludedStepsValue(...e);
  }
  getIncludedScaleSteps(...e) {
    return t(this, o).getIncludedStepsValue(...e);
  }
  deletePositionStep(...e) {
    t(this, n).deleteStep(...e);
  }
  getExcludedPositionSteps(...e) {
    return t(this, n).getExcludedStepsValue(...e);
  }
  getIncludedPositionSteps(...e) {
    return t(this, n).getIncludedStepsValue(...e);
  }
  deleteRotationStep(...e) {
    t(this, c).deleteStep(...e);
  }
  deleteScaleStep(...e) {
    t(this, o).deleteStep(...e);
  }
  onPosition(...e) {
    return t(this, n).subscribe(...e);
  }
  offPosition(...e) {
    t(this, n).unsubscribe(...e);
  }
  onScale(...e) {
    return t(this, o).subscribe(...e);
  }
  offScale(...e) {
    t(this, o).unsubscribe(...e);
  }
  onRotation(...e) {
    return t(this, c).subscribe(...e);
  }
  offRotation(...e) {
    t(this, c).unsubscribe(...e);
  }
  onResize(...e) {
    return t(this, T).subscribe(...e);
  }
  offResize(...e) {
    return t(this, T).unsubscribe(...e);
  }
}
a = new WeakMap(), z = new WeakMap(), b = new WeakMap(), _ = new WeakMap(), W = new WeakMap(), X = new WeakMap(), v = new WeakMap(), w = new WeakMap(), q = new WeakMap(), B = new WeakMap(), x = new WeakMap(), M = new WeakMap(), Y = new WeakMap(), S = new WeakMap(), d = new WeakMap(), C = new WeakMap(), H = new WeakMap(), I = new WeakMap(), D = new WeakMap(), p = new WeakMap(), g = new WeakMap(), m = new WeakMap(), c = new WeakMap(), n = new WeakMap(), o = new WeakMap(), E = new WeakMap(), R = new WeakMap(), T = new WeakMap(), f = new WeakSet(), J = function() {
  t(this, o).calculate(), t(this, n).calculate(), t(this, c).calculate();
}, ht = function() {
  t(this, o).setStep("_size", "+", {
    x: t(this, v) ? t(this, x) : 1,
    y: t(this, v) ? t(this, M) : 1,
    z: t(this, v) ? t(this, Y) : 1
  });
  const e = t(this, w) ? t(this, H) : 0, s = t(this, w) ? t(this, I) : 0, l = t(this, w) ? t(this, D) : 0;
  t(this, n).setStep("_position", "+", {
    x: e,
    y: s,
    z: l
  }), t(this, q) ? (t(this, o).setStep("_scale", "*", {
    x: t(this, m).x,
    y: t(this, m).y,
    z: t(this, m).z
  }), t(this, n).setStep("_translation", "+", {
    x: t(this, p).x,
    y: t(this, p).y,
    z: t(this, p).z
  }), t(this, c).setStep("_rotation", "+", {
    x: t(this, g).x,
    y: t(this, g).y,
    z: t(this, g).z
  })) : (t(this, o).setStep("_scale", "*", {
    x: 1,
    y: 1,
    z: 1
  }), t(this, n).setStep("_translation", "+", {
    x: 0,
    y: 0,
    z: 0
  }), t(this, c).setStep("_rotation", "+", {
    x: 0,
    y: 0,
    z: 0
  }));
}, rt = function() {
  const e = getComputedStyle(t(this, a));
  r(this, x, Math.max(t(this, a).clientWidth, 1)), r(this, M, Math.max(t(this, a).clientHeight, 1)), r(this, Y, Math.max(
    ut.parse(e.getPropertyValue("--depth") || "0px"),
    1
  ));
  const s = F(t(this, z)), l = G(t(this, z)), y = t(this, z).clientWidth, A = t(this, z).clientHeight;
  if (r(this, d, F(t(this, a)) - s), r(this, S, G(t(this, a)) - l), t(this, _) === "z") {
    const V = t(this, d) / y, O = t(this, S) / A;
    r(this, d, (V - Math.floor(V)) * y), r(this, S, (O - Math.floor(O)) * A), t(this, W) === "left" ? r(this, C, F(t(this, a)) - s - t(this, d)) : r(this, C, G(t(this, a)) - l - t(this, S));
  }
  if (r(this, d, t(this, d) + t(this, a).clientLeft), r(this, S, t(this, S) + t(this, a).clientTop), t(this, X)) {
    const V = Math.round(y / 2), O = Math.round(A / 2), lt = t(this, x) ? Math.round(t(this, x) / 2) : 0, ot = t(this, M) ? Math.round(t(this, M) / 2) : 0, ct = t(this, d) - V + lt, at = (t(this, S) - O + ot) * -1;
    r(this, H, ct), r(this, I, at);
  } else
    r(this, H, t(this, d)), r(this, I, t(this, S));
  r(this, D, t(this, C) * -1);
  const k = new WebKitCSSMatrix(e.transform), u = pt(k);
  t(this, p).x = u.translationX, t(this, p).y = u.translationY, t(this, p).z = u.translationZ, t(this, m).x = u.scaleX, t(this, m).y = u.scaleY, t(this, m).z = u.scaleZ, t(this, g).x = u.rotationX, t(this, g).y = u.rotationY, t(this, g).z = u.rotationZ, L(this, f, ht).call(this), L(this, f, J).call(this), t(this, T).notify();
}, nt = function() {
  t(this, E).x = 0, t(this, E).y = 0, t(this, E).z = 0;
  for (let e = 0; e < t(this, b).length; e++) {
    const s = t(this, b)[e]();
    let l = s.axis;
    t(this, _) !== "auto" && (l = t(this, _));
    const y = s.value * (l === "x" ? -1 : t(this, X) ? 1 : -1);
    t(this, E)[l] += y, t(this, n).setStep(`_scroll_${e}`, "+", {
      [l]: y
    });
  }
}, P = new WeakMap(), U = new WeakMap(), Z = new WeakMap();
export {
  Ct as LayoutBox,
  pt as decomposeCSSMatrix
};

==> aptechka-0.42.5.tgz: package/lib/layout-box/index.js <==
var Q = (i) => {
  throw TypeError(i);
};
var K = (i, e, s) => e.has(i) || Q("Cannot " + s);
var t = (i, e, s) => (K(i, e, "read from private field"), s ? s.call(i) : e.get(i)), h = (i, e, s) => e.has(i) ? Q("Cannot add the same private member more than once") : e instanceof WeakSet ? e.add(i) : e.set(i, s), r = (i, e, s, l) => (K(i, e, "write to private field"), l ? l.call(i, s) : e.set(i, s), s), L = (i, e, s) => (K(i, e, "access private method"), s);
import { cssUnitParser as ut } from "../css-unit-parser/index.js";
import { Ladder as N } from "../ladder/index.js";
import { RESIZE_ORDER as St, TICK_ORDER as dt } from "../order/index.js";
import { scrollEntries as $ } from "../scroll-entries/index.js";
import { ticker as j } from "../ticker/index.js";
import { i as tt } from "../browser-0zX67oeU.js";
import { g as et } from "../dom-CVWzyXPH.js";
import { g as F, a as G } from "../layout-DpZo-I0y.js";
import { elementResizer as st } from "../element-resizer/index.js";
import { windowResizer as it } from "../window-resizer/index.js";
import { Notifier as ft } from "../notifier/index.js";
function pt(i) {
  const e = Math.sqrt(
    i.m11 * i.m11 + i.m12 * i.m12 + i.m13 * i.m13
  ), s = Math.sqrt(
    i.m21 * i.m21 + i.m22 * i.m22 + i.m23 * i.m23
  ), l = Math.sqrt(
    i.m31 * i.m31 + i.m32 * i.m32 + i.m33 * i.m33
  ), y = Math.atan2(i.m32, i.m33), A = Math.atan2(
    -i.m31,
    Math.sqrt(i.m32 * i.m32 + i.m33 * i.m33)
  ), k = Math.atan2(i.m21, i.m11), u = i.m41, V = i.m42 * -1, O = i.m43;
  return {
    scaleX: e,
    scaleY: s,
    scaleZ: l,
    rotationX: y,
    rotationY: A,
    rotationZ: k,
    translationX: u,
    translationY: V,
    translationZ: O
  };
}
var a, z, b, _, W, X, v, w, q, B, x, M, Y, S, d, C, H, I, D, p, g, m, c, n, o, E, R, T, f, J, ht, rt, nt, P, U, Z;
class Ct {
  constructor(e, s) {
    h(this, f);
    h(this, a, null);
    h(this, z, null);
    h(this, b, []);
    h(this, _, "auto");
    h(this, W, "top");
    h(this, X, !1);
    h(this, v, !0);
    h(this, w, !0);
    h(this, q, !0);
    h(this, B, !0);
    h(this, x, 0);
    h(this, M, 0);
    h(this, Y, 0);
    h(this, S, 0);
    h(this, d, 0);
    h(this, C, 0);
    h(this, H, 0);
    h(this, I, 0);
    h(this, D, 0);
    h(this, p, { x: 0, y: 0, z: 0 });
    h(this, g, { x: 0, y: 0, z: 0 });
    h(this, m, { x: 1, y: 1, z: 1 });
    h(this, c, new N({ x: 0, y: 0, z: 0 }));
    h(this, n, new N({ x: 0, y: 0, z: 0 }));
    h(this, o, new N({ x: 0, y: 0, z: 0 }));
    h(this, E, { x: 0, y: 0, z: 0 });
    h(this, R, /* @__PURE__ */ new Map());
    h(this, T, new ft());
    h(this, P, () => {
      tt && L(this, f, rt).call(this);
    });
    h(this, U, () => {
      L(this, f, nt).call(this), L(this, f, J).call(this);
    });
    h(this, Z, () => {
      const e = $.getAll(this.element);
      t(this, R).forEach((s, l) => {
        e.includes(l) || (this.deleteScrollStep(s), t(this, R).delete(l));
      }), e.forEach((s) => {
        if (!t(this, R).has(s)) {
          const l = () => s;
          t(this, R).set(s, l), this.setScrollStep(l);
        }
      });
    });
    tt && (r(this, a, et(e) || document.body), r(this, z, et(s == null ? void 0 : s.containerElement) || document.body), r(this, _, (s == null ? void 0 : s.scrollAxis) || "auto"), r(this, W, (s == null ? void 0 : s.frontSide) || "top"), r(this, X, (s == null ? void 0 : s.cartesian) || !1), r(this, v, (s == null ? void 0 : s.sizeStep) !== void 0 ? s.sizeStep : !0), r(this, w, (s == null ? void 0 : s.positionStep) !== void 0 ? s.positionStep : !0), r(this, q, (s == null ? void 0 : s.transformStep) !== void 0 ? s.transformStep : !0), r(this, B, (s == null ? void 0 : s.scrollStep) !== void 0 ? s.scrollStep : !0), t(this, o).setStep("_size", "+", {
      x: 1,
      y: 1,
      z: 1
    }), t(this, n).setStep("_position", "+", {
      x: 0,
      y: 0,
      z: 0
    }), t(this, o).setStep("_scale", "*", {
      x: 1,
      y: 1,
      z: 1
    }), t(this, n).setStep("_translation", "+", {
      x: 0,
      y: 0,
      z: 0
    }), t(this, c).setStep("_rotation", "+", {
      x: 0,
      y: 0,
      z: 0
    }), t(this, B) && ($.notifier.subscribe(t(this, Z)), t(this, Z).call(this)), st.subscribe(this.element, t(this, P)), it.subscribe(t(this, P), St.LAYOUT_BOX), j.subscribe(t(this, U), {
      order: dt.LAYOUT_BOX,
      culling: s != null && s.culling ? this.element : void 0
    }));
  }
  get element() {
    return t(this, a);
  }
  get containerElement() {
    return t(this, z);
  }
  get position() {
    return t(this, n).current;
  }
  get rotation() {
    return t(this, c).current;
  }
  get scale() {
    return t(this, o).current;
  }
  get scrollValue() {
    return t(this, E);
  }
  get left() {
    return t(this, d);
  }
  get top() {
    return t(this, S);
  }
  get CSSTranslation() {
    return t(this, p);
  }
  get CSSRotation() {
    return t(this, g);
  }
  get CSSScale() {
    return t(this, m);
  }
  get front() {
    return t(this, C);
  }
  get width() {
    return t(this, x);
  }
  get height() {
    return t(this, M);
  }
  get depth() {
    return t(this, Y);
  }
  destroy() {
    j.unsubscribe(t(this, U)), st.unsubscribe(t(this, P)), it.unsubscribe(t(this, P)), $.notifier.unsubscribe(t(this, Z)), t(this, R).clear(), t(this, n).close(), t(this, c).close(), t(this, o).close();
  }
  bindObject(e) {
    e.position && t(this, n).bind(e.position), e.rotation && t(this, c).bind(e.rotation), e.scale && t(this, o).bind(e.scale);
  }
  unbindObject(e) {
    e.position && t(this, n).unbind(e.position), e.rotation && t(this, c).unbind(e.rotation), e.scale && t(this, o).unbind(e.scale);
  }
  setScrollStep(e) {
    return t(this, b).includes(e) || t(this, b).push(e), () => this.deleteScrollStep(e);
  }
  deleteScrollStep(e) {
    r(this, b, t(this, b).filter(
      (s) => s !== e
    ));
  }
  setPositionStep(...e) {
    t(this, n).setStep(...e);
  }
  getPositionStep(...e) {
    return t(this, n).getStepValue(...e);
  }
  setRotationStep(...e) {
    t(this, c).setStep(...e);
  }
  getRotationStep(...e) {
    return t(this, c).getStepValue(...e);
  }
  getExcludedRotationSteps(...e) {
    return t(this, c).getExcludedStepsValue(...e);
  }
  getIncludedRotationSteps(...e) {
    return t(this, c).getIncludedStepsValue(...e);
  }
  setScaleStep(...e) {
    t(this, o).setStep(...e);
  }
  getScaleStep(...e) {
    return t(this, o).getStepValue(...e);
  }
  getExcludedScaleSteps(...e) {
    return t(this, o).getExcludedStepsValue(...e);
  }
  getIncludedScaleSteps(...e) {
    return t(this, o).getIncludedStepsValue(...e);
  }
  deletePositionStep(...e) {
    t(this, n).deleteStep(...e);
  }
  getExcludedPositionSteps(...e) {
    return t(this, n).getExcludedStepsValue(...e);
  }
  getIncludedPositionSteps(...e) {
    return t(this, n).getIncludedStepsValue(...e);
  }
  deleteRotationStep(...e) {
    t(this, c).deleteStep(...e);
  }
  deleteScaleStep(...e) {
    t(this, o).deleteStep(...e);
  }
  onPosition(...e) {
    return t(this, n).subscribe(...e);
  }
  offPosition(...e) {
    t(this, n).unsubscribe(...e);
  }
  onScale(...e) {
    return t(this, o).subscribe(...e);
  }
  offScale(...e) {
    t(this, o).unsubscribe(...e);
  }
  onRotation(...e) {
    return t(this, c).subscribe(...e);
  }
  offRotation(...e) {
    t(this, c).unsubscribe(...e);
  }
  onResize(...e) {
    return t(this, T).subscribe(...e);
  }
  offResize(...e) {
    return t(this, T).unsubscribe(...e);
  }
}
a = new WeakMap(), z = new WeakMap(), b = new WeakMap(), _ = new WeakMap(), W = new WeakMap(), X = new WeakMap(), v = new WeakMap(), w = new WeakMap(), q = new WeakMap(), B = new WeakMap(), x = new WeakMap(), M = new WeakMap(), Y = new WeakMap(), S = new WeakMap(), d = new WeakMap(), C = new WeakMap(), H = new WeakMap(), I = new WeakMap(), D = new WeakMap(), p = new WeakMap(), g = new WeakMap(), m = new WeakMap(), c = new WeakMap(), n = new WeakMap(), o = new WeakMap(), E = new WeakMap(), R = new WeakMap(), T = new WeakMap(), f = new WeakSet(), J = function() {
  t(this, o).calculate(), t(this, n).calculate(), t(this, c).calculate();
}, ht = function() {
  t(this, o).setStep("_size", "+", {
    x: t(this, v) ? t(this, x) : 1,
    y: t(this, v) ? t(this, M) : 1,
    z: t(this, v) ? t(this, Y) : 1
  });
  const e = t(this, w) ? t(this, H) : 0, s = t(this, w) ? t(this, I) : 0, l = t(this, w) ? t(this, D) : 0;
  t(this, n).setStep("_position", "+", {
    x: e,
    y: s,
    z: l
  }), t(this, q) ? (t(this, o).setStep("_scale", "*", {
    x: t(this, m).x,
    y: t(this, m).y,
    z: t(this, m).z
  }), t(this, n).setStep("_translation", "+", {
    x: t(this, p).x,
    y: t(this, p).y,
    z: t(this, p).z
  }), t(this, c).setStep("_rotation", "+", {
    x: t(this, g).x,
    y: t(this, g).y,
    z: t(this, g).z
  })) : (t(this, o).setStep("_scale", "*", {
    x: 1,
    y: 1,
    z: 1
  }), t(this, n).setStep("_translation", "+", {
    x: 0,
    y: 0,
    z: 0
  }), t(this, c).setStep("_rotation", "+", {
    x: 0,
    y: 0,
    z: 0
  }));
}, rt = function() {
  const e = getComputedStyle(t(this, a));
  r(this, x, Math.max(t(this, a).clientWidth, 1)), r(this, M, Math.max(t(this, a).clientHeight, 1)), r(this, Y, Math.max(
    ut.parse(e.getPropertyValue("--depth") || "0px"),
    1
  ));
  const s = F(t(this, z)), l = G(t(this, z)), y = t(this, z).clientWidth, A = t(this, z).clientHeight;
  if (r(this, d, F(t(this, a)) - s), r(this, S, G(t(this, a)) - l), t(this, _) === "z") {
    const V = t(this, d) / y, O = t(this, S) / A;
    r(this, d, (V - Math.floor(V)) * y), r(this, S, (O - Math.floor(O)) * A), t(this, W) === "left" ? r(this, C, F(t(this, a)) - s - t(this, d)) : r(this, C, G(t(this, a)) - l - t(this, S));
  }
  if (r(this, d, t(this, d) + t(this, a).clientLeft), r(this, S, t(this, S) + t(this, a).clientTop), t(this, X)) {
    const V = Math.round(y / 2), O = Math.round(A / 2), lt = t(this, x) ? Math.round(t(this, x) / 2) : 0, ot = t(this, M) ? Math.round(t(this, M) / 2) : 0, ct = t(this, d) - V + lt, at = (t(this, S) - O + ot) * -1;
    r(this, H, ct), r(this, I, at);
  } else
    r(this, H, t(this, d)), r(this, I, t(this, S));
  r(this, D, t(this, C) * -1);
  const k = new WebKitCSSMatrix(e.transform), u = pt(k);
  t(this, p).x = u.translationX, t(this, p).y = u.translationY, t(this, p).z = u.translationZ, t(this, m).x = u.scaleX, t(this, m).y = u.scaleY, t(this, m).z = u.scaleZ, t(this, g).x = u.rotationX, t(this, g).y = u.rotationY, t(this, g).z = u.rotationZ, L(this, f, ht).call(this), L(this, f, J).call(this), t(this, T).notify();
}, nt = function() {
  t(this, E).x = 0, t(this, E).y = 0, t(this, E).z = 0;
  for (let e = 0; e < t(this, b).length; e++) {
    const s = t(this, b)[e]();
    let l = s.axis;
    t(this, _) !== "auto" && (l = t(this, _));
    const y = s.value * (l === "x" ? -1 : t(this, X) ? 1 : -1);
    t(this, E)[l] += y, t(this, n).setStep(`_scroll_${e}`, "+", {
      [l]: y
    });
  }
}, P = new WeakMap(), U = new WeakMap(), Z = new WeakMap();
export {
  Ct as LayoutBox,
  pt as decomposeCSSMatrix
};
